# mka_eureka_microservice_controllers
A pip package contains scripts to easily connection between connected django microservice with eureka
## Authors
- [@adnan-aji](https://github.com/adnan-aji)
## Installation
Install my-project with pip
```bash
  pip install mka_eureka_microservice_controllers
```
## Requirements
* django
* django_numpy_json_encoder
* py_eureka_client
* pathlib
* pandas
* numpy

